window.Gleam.initSearch([{"doc":"lustre_virtual_list","title":"lustre_virtual_list","content":"\n# Lustre Virtual List\n\nThis is a basic virtual list component for rendering very large lists without performance problems.\nIt renders only a subset of items at a time, based on which items are scrolled into the view.\n\n# How To Use\n\nBefore you start your lustre app, register the virtual list component.\n\n```gleam\nlustre_virtual_list.register()\n```\n\nIn your view function, just call the virtual_list to render a virtual list.\n\n```gleam\nvirtual_list(\n  items: list.range(1, 100_000),\n  render: fn(item: Int) {\n    html.div([on_click(ItemClick(item)), class(&quot;item&quot;)], [\n      text(&quot;Item #&quot; &lt;&gt; int.to_string(item)),\n    ])\n  },\n  item_height: 24,\n  item_count: 40,\n  attributes: [class(&quot;list&quot;)],\n),\n```\n\n&gt; [!NOTE]\n&gt; We recommend only creating virtual lists using the `virtual_list` function, not using the element directly.\n\n1. `items` is a list of items that will be passed to your render function.\n2. `render` is a view funciton that receives one item and should return the Element to render.\n3. `item_height` you must specify the height of each item so we can calculate the total size of the list.\n4. `item_count` specify how many items should be rendered at a time.\n5. `attributes` any additional attributes you want to add to the component, for example a class.\n\n## Example\n\nYou can run the example in the example folder with the following command.\n```\ncd example\ngleam run -m lustre/dev start\n```\n\n# lustre_virtual_list\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre_virtual_list)](https://hex.pm/packages/lustre_virtual_list)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lustre_virtual_list/)\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add lustre_virtual_list\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/lustre_virtual_list&gt;.\n","url":"index.html"},{"doc":"lustre_virtual_list","title":"register","content":"pub fn register() -&gt; Nil\n call this at the beginning of your program to register the virtual list component\nSynonyms:\nlustre_virtual_list.register\nlustre_virtual_list register","url":"lustre_virtual_list.html#register"},{"doc":"lustre_virtual_list","title":"virtual_list","content":"pub fn virtual_list(\n  items items: List(a),\n  render render_item: fn(a) -&gt; Element(b),\n  item_height item_height: Int,\n  item_count item_count: Int,\n  attributes attributes: List(Attribute(b)),\n) -&gt; Element(b)\n render a virtual list of items\n\n items: the list of items to virtualise\n\n render: a function that renders an item\n\n item_height: you must specify the height of an item\n\n item_count: you must specify how many items to render at most\n\n attributes: optional attributes (e.g. styles)\nSynonyms:\nlustre_virtual_list.virtual_list\nlustre_virtual_list virtual_list","url":"lustre_virtual_list.html#virtual_list"},{"doc":"lustre_virtual_list","title":"lustre_virtual_list","content":"","url":"lustre_virtual_list.html"}]);